@@ -1,7 +1,10 @@
 #' @importFrom glue glue
 #' @importFrom attempt warn_if_not
 
-create_dockerfile <- function(FROM = "rocker/r-base", AS = NULL){
+create_dockerfile <- function(
+  FROM = "rocker/r-base",
+  AS = NULL
+){
   if (is.null(AS)) {
     glue("FROM {FROM}")
   } else {
@@ -14,18 +17,42 @@ add_run <- function(cmd){
   glue("RUN {cmd}")
 }
 
-add_add <- function(from, to, force = TRUE){
+add_add <- function(
+  from,
+  to,
+  force = TRUE
+){
   if (!force) {
-    warn_if_not(normalizePath(from), file.exists, "The file `from` doesn't seem to exists")
-    warn_if_not(normalizePath(to), file.exists, "The file `to` doesn't seem to exists.")
+    warn_if_not(
+      normalizePath(from),
+      file.exists,
+      "The file `from` doesn't seem to exists"
+    )
+    warn_if_not(
+      normalizePath(to),
+      file.exists,
+      "The file `to` doesn't seem to exists."
+    )
   }
   glue("ADD {from} {to}")
 }
 
-add_copy <- function(from, to, force = TRUE){
+add_copy <- function(
+  from,
+  to,
+  force = TRUE
+){
   if (!force) {
-    warn_if_not(normalizePath(from), file.exists, "The file `from` doesn't seem to exists")
-    warn_if_not(normalizePath(to), file.exists, "The file `to` doesn't seem to exists.")
+    warn_if_not(
+      normalizePath(from),
+      file.exists,
+      "The file `from` doesn't seem to exists"
+    )
+    warn_if_not(
+      normalizePath(to),
+      file.exists,
+      "The file `to` doesn't seem to exists."
+    )
   }
   glue("COPY {from} {to}")
 }
@@ -35,7 +62,11 @@ add_workdir <- function(where){
 }
 
 add_expose <- function(port){
-  warn_if_not(port, is.numeric, "You've entered a character vector")
+  warn_if_not(
+    port,
+    is.numeric,
+    "You've entered a character vector"
+  )
   glue("EXPOSE {port}")
 }
 
@@ -101,3 +132,7 @@ switch_them <- function(vec, a, b){
 remove_from <- function(vec, what){
   vec[-what]
 }
+
+add_to <- function(vec, cmd, after){
+  append(vec, cmd, after)
+}
